==> cppad_2016.00.00.1.orig.tar.gz: cppad-20160000.1/doc/_sub_sparse_hes.cpp_xml.js <==
var list_across0 = [
'_contents_xml.htm',
'_reference.xml',
'_index.xml',
'_search_xml.htm',
'_external.xml'
];
var list_up0 = [
'cppad.xml',
'adfun.xml',
'drivers.xml',
'sparse_hessian.xml',
'sub_sparse_hes.cpp.xml'
];
var list_down3 = [
'independent.xml',
'funconstruct.xml',
'dependent.xml',
'abort_recording.xml',
'seq_property.xml',
'funeval.xml',
'drivers.xml',
'funcheck.xml',
'optimize.xml',
'check_for_nan.xml'
];
var list_down2 = [
'jacobian.xml',
'forone.xml',
'revone.xml',
'hessian.xml',
'fortwo.xml',
'revtwo.xml',
'sparse_jacobian.xml',
'sparse_hessian.xml'
];
var list_down1 = [
'sparse_hessian.cpp.xml',
'sub_sparse_hes.cpp.xml',
'sparse_sub_hes.cpp.xml'
];
var list_current0 = [
'sub_sparse_hes.cpp.xml#Purpose',
'sub_sparse_hes.cpp.xml#See Also',
'sub_sparse_hes.cpp.xml#Function',
'sub_sparse_hes.cpp.xml#Subset',
'sub_sparse_hes.cpp.xml#Example'
];
function choose_across0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_across0[index-1];
}
function choose_up0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_up0[index-1];
}
function choose_down3(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down3[index-1];
}
function choose_down2(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down2[index-1];
}
function choose_down1(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down1[index-1];
}
function choose_down0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down0[index-1];
}
function choose_current0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_current0[index-1];
}

==> cppad_2018.00.00.0.orig.tar.gz: cppad-20180000.0/doc/_sub_sparse_hes.cpp_xml.js <==
var list_across0 = [
'_contents_xml.htm',
'_reference.xml',
'_index.xml',
'_search_xml.htm',
'_external.xml'
];
var list_up0 = [
'cppad.xml',
'adfun.xml',
'sparse_derivative.xml',
'sparse_hessian.xml',
'sub_sparse_hes.cpp.xml'
];
var list_down3 = [
'record_adfun.xml',
'drivers.xml',
'forward.xml',
'reverse.xml',
'sparsity_pattern.xml',
'sparse_derivative.xml',
'optimize.xml',
'abs_normal.xml',
'funcheck.xml',
'check_for_nan.xml'
];
var list_down2 = [
'sparse_jac.xml',
'sparse_jacobian.xml',
'sparse_hes.xml',
'sparse_hessian.xml',
'subgraph_jac_rev.xml'
];
var list_down1 = [
'sparse_hessian.cpp.xml',
'sub_sparse_hes.cpp.xml',
'sparse_sub_hes.cpp.xml'
];
var list_current0 = [
'sub_sparse_hes.cpp.xml#Purpose',
'sub_sparse_hes.cpp.xml#See Also',
'sub_sparse_hes.cpp.xml#Function',
'sub_sparse_hes.cpp.xml#Subset',
'sub_sparse_hes.cpp.xml#Example'
];
function choose_across0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_across0[index-1];
}
function choose_up0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_up0[index-1];
}
function choose_down3(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down3[index-1];
}
function choose_down2(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down2[index-1];
}
function choose_down1(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down1[index-1];
}
function choose_down0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down0[index-1];
}
function choose_current0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_current0[index-1];
}
